Value

Type Alias Value 

pub type Value = Value;
Represents a dynamically typed value which can be either an int64, a double, a string, a bool, a unix milliseconds, or a bytes array.

Aliased Type

pub enum Value {}